@@ -86,6 +86,7 @@
 #define scheme_add_flush (scheme_extension_table->scheme_add_flush)
 #define scheme_remove_flush (scheme_extension_table->scheme_remove_flush)
 #define scheme_add_atexit_closer (scheme_extension_table->scheme_add_atexit_closer)
+#define scheme_atexit (scheme_extension_table->scheme_atexit)
 #define scheme_add_evt (scheme_extension_table->scheme_add_evt)
 #define scheme_add_evt_through_sema (scheme_extension_table->scheme_add_evt_through_sema)
 #define scheme_is_evt (scheme_extension_table->scheme_is_evt)
@@ -118,6 +119,7 @@
 #define scheme_log_abort (scheme_extension_table->scheme_log_abort)
 #define scheme_log_warning (scheme_extension_table->scheme_log_warning)
 #define scheme_glib_log_message (scheme_extension_table->scheme_glib_log_message)
+#define scheme_glib_log_message_test (scheme_extension_table->scheme_glib_log_message_test)
 #define scheme_out_of_memory_abort (scheme_extension_table->scheme_out_of_memory_abort)
 #define scheme_wrong_count (scheme_extension_table->scheme_wrong_count)
 #define scheme_wrong_count_m (scheme_extension_table->scheme_wrong_count_m)
@@ -209,11 +211,6 @@
 #define scheme_extract_one_cc_mark (scheme_extension_table->scheme_extract_one_cc_mark)
 #define scheme_extract_one_cc_mark_to_tag (scheme_extension_table->scheme_extract_one_cc_mark_to_tag)
 #define scheme_do_eval (scheme_extension_table->scheme_do_eval)
-#define scheme_eval_compiled_stx_string (scheme_extension_table->scheme_eval_compiled_stx_string)
-#define scheme_load_compiled_stx_string (scheme_extension_table->scheme_load_compiled_stx_string)
-#define scheme_compiled_stx_symbol (scheme_extension_table->scheme_compiled_stx_symbol)
-#define scheme_eval_compiled_sized_string (scheme_extension_table->scheme_eval_compiled_sized_string)
-#define scheme_eval_compiled_sized_string_with_magic (scheme_extension_table->scheme_eval_compiled_sized_string_with_magic)
 #define scheme_detach_multple_array (scheme_extension_table->scheme_detach_multple_array)
 #ifndef SCHEME_NO_GC
 # ifndef SCHEME_NO_GC_PROTO
@@ -305,7 +302,6 @@
 #define scheme_hash_table_index (scheme_extension_table->scheme_hash_table_index)
 #define scheme_hash_table_next (scheme_extension_table->scheme_hash_table_next)
 #define scheme_make_hash_tree (scheme_extension_table->scheme_make_hash_tree)
-#define scheme_make_hash_tree_set (scheme_extension_table->scheme_make_hash_tree_set)
 #define scheme_hash_tree_set (scheme_extension_table->scheme_hash_tree_set)
 #define scheme_hash_tree_get (scheme_extension_table->scheme_hash_tree_get)
 #define scheme_eq_hash_tree_get (scheme_extension_table->scheme_eq_hash_tree_get)
@@ -580,10 +576,6 @@
 #define scheme_make_sized_offset_path (scheme_extension_table->scheme_make_sized_offset_path)
 #define scheme_make_sized_offset_kind_path (scheme_extension_table->scheme_make_sized_offset_kind_path)
 #define scheme_make_path_without_copying (scheme_extension_table->scheme_make_path_without_copying)
-#ifdef MACINTOSH_EVENTS
-#define scheme_mac_spec_to_path (scheme_extension_table->scheme_mac_spec_to_path)
-#define scheme_mac_path_to_spec (scheme_extension_table->scheme_mac_path_to_spec)
-#endif
 #define scheme_alloc_fdset_array (scheme_extension_table->scheme_alloc_fdset_array)
 #define scheme_init_fdset_array (scheme_extension_table->scheme_init_fdset_array)
 #define scheme_get_fdset (scheme_extension_table->scheme_get_fdset)
@@ -618,21 +610,20 @@
 #define scheme_make_envunbox (scheme_extension_table->scheme_make_envunbox)
 #define scheme_lookup_global (scheme_extension_table->scheme_lookup_global)
 #define scheme_global_bucket (scheme_extension_table->scheme_global_bucket)
-#define scheme_global_keyword_bucket (scheme_extension_table->scheme_global_keyword_bucket)
 #define scheme_module_bucket (scheme_extension_table->scheme_module_bucket)
 #define scheme_builtin_value (scheme_extension_table->scheme_builtin_value)
 #define scheme_set_global_bucket (scheme_extension_table->scheme_set_global_bucket)
-#define scheme_install_macro (scheme_extension_table->scheme_install_macro)
-#define scheme_save_initial_module_set (scheme_extension_table->scheme_save_initial_module_set)
 #define scheme_primitive_module (scheme_extension_table->scheme_primitive_module)
 #define scheme_finish_primitive_module (scheme_extension_table->scheme_finish_primitive_module)
 #define scheme_set_primitive_module_phaseless (scheme_extension_table->scheme_set_primitive_module_phaseless)
 #define scheme_protect_primitive_provide (scheme_extension_table->scheme_protect_primitive_provide)
 #define scheme_make_modidx (scheme_extension_table->scheme_make_modidx)
-#define scheme_apply_for_syntax_in_env (scheme_extension_table->scheme_apply_for_syntax_in_env)
 #define scheme_dynamic_require (scheme_extension_table->scheme_dynamic_require)
+#define scheme_dynamic_require_reader (scheme_extension_table->scheme_dynamic_require_reader)
 #define scheme_namespace_require (scheme_extension_table->scheme_namespace_require)
 #define scheme_is_module_path (scheme_extension_table->scheme_is_module_path)
+#define scheme_is_module_path_index (scheme_extension_table->scheme_is_module_path_index)
+#define scheme_is_resolved_module_path (scheme_extension_table->scheme_is_resolved_module_path)
 #define scheme_datum_to_kernel_stx (scheme_extension_table->scheme_datum_to_kernel_stx)
 #define scheme_module_is_declared (scheme_extension_table->scheme_module_is_declared)
 #define scheme_intern_symbol (scheme_extension_table->scheme_intern_symbol)
@@ -701,7 +692,7 @@
 #define scheme_make_ephemeron (scheme_extension_table->scheme_make_ephemeron)
 #define scheme_ephemeron_value (scheme_extension_table->scheme_ephemeron_value)
 #define scheme_ephemeron_key (scheme_extension_table->scheme_ephemeron_key)
-#define scheme_make_stubborn_will_executor (scheme_extension_table->scheme_make_stubborn_will_executor)
+#define scheme_make_late_will_executor (scheme_extension_table->scheme_make_late_will_executor)
 #define scheme_load (scheme_extension_table->scheme_load)
 #define scheme_load_extension (scheme_extension_table->scheme_load_extension)
 #define scheme_register_extension_global (scheme_extension_table->scheme_register_extension_global)
@@ -732,6 +723,7 @@
 #define scheme_free_key (scheme_extension_table->scheme_free_key)
 #define scheme_jit_find_code_end (scheme_extension_table->scheme_jit_find_code_end)
 #define scheme_jit_now (scheme_extension_table->scheme_jit_now)
+#define scheme_set_signal_handler (scheme_extension_table->scheme_set_signal_handler)
 #ifdef MZ_PRECISE_GC
 #pragma GC_VARIABLE_STACK_THOUGH_TABLE
 #endif
